"""

    """

import sys

from .auto import dl_and_ret_dirpath


if __name__ == '__main__' :
    conf_fp = sys.argv[1]
    dl_and_ret_dirpath(conf_fp)
